text_en = """Do not forget about Momofuku Ando! He created instant noodles in Osaka. At that location, Nissin was founded. Many students survived by eating his noodles, but they don't even know him."""
text_nl = """Vergeet Momofuku Ando niet! Hij maakte instantnoedels in Osaka. Op die locatie werd Nissin opgericht. Veel studenten overleefden door zijn noedels te eten, maar ze kennen zijn naam niet eens."""
text_de = """Vergiss Momofuku Ando nicht! Er kreierte Instantnudeln in Osaka. An diesem Standort wurde Nissin gegründet. Viele Studenten überlebten, indem sie seine Nudeln aßen, aber sie kennen ihn nicht einmal."""
text_dk = """Glem ikke Momofuku Ando! Han skabte instant nudler i Osaka. På det sted blev Nissin grundlagt. Mange elever overlevede ved at spise hans nudler, men de kender ham ikke engang."""
text_fr = """N'oubliez pas Momofuku Ando ! Il a créé des nouilles instantanées à Osaka. À cet endroit, Nissin a été fondée. De nombreux étudiants ont survécu en mangeant ses nouilles, mais ils ne le connaissent même pas."""
text_es = """¡No te olvides de Momofuku Ando! Creó fideos instantáneos en Osaka. En ese lugar, se fundó Nissin. Muchos estudiantes sobrevivieron comiendo sus fideos, pero ni siquiera lo conocen."""
text_it = """Non dimenticare Momofuku Ando! Ha creato spaghetti istantanei a Osaka. In quel luogo è stata fondata Nissin. Molti studenti sono sopravvissuti mangiando i suoi noodles, ma non lo conoscono nemmeno."""

texts = [text_en, text_nl, text_de, text_dk, text_fr, text_es, text_it]
